@@ -7,3 +7,6 @@ from .resnet50 import load_ResNet50
 from .efficientnetb0 import load_EfficientNetB0
 from .vgg16 import load_VGG16
 from .vit import load_ViT_B16
+from .convnext import load_tiny_ConvNeXT
+from .maxvit import load_tiny_MaxViT
+from .levit import load_LeViT_small
